

require 'ProteinTranslate/protein'

describe ProteinTranslate::ProteinTranslate do
	before :each do
		@protein = ProteinTranslate::ProteinTranslate.new
	end

	context "#Basic"do

		it "Debe exisistir un objeto de la clase ProteinTranslate::ProteinTranslate"do
			expect(@protein).not_to eq(nil)
		end

		it "Debe existir un hash que contenga las equivalencias"do
			expect(@protein.equivalence).not_to eq(nil)
		end

	end

	context "#Methionine" do
		it "Debe tener la equivalencia para AUG"do
			expect(@protein.equivalence["AUG"]).to eq("Methionine")
		end
	end

	context "#Phenylalanine" do

		it "Debe tener la equivalencia para UUU" do
			expect(@protein.equivalence["UUU"]).to eq("Phenylalanine")
		end
		it "Debe tener la otra equivalencia para Phenylalanine"do
			expect(@protein.equivalence["UUC"]).to eq("Phenylalanine")
		end
	end

	context "#Leucine"do
		it "Debe tener una de las equivalencias a Leucine" do
			expect(@protein.equivalence["UUA"]).to eq("Leucine")
		end
		it "UUG tambien es una equivalencia para Leucina"do
			expect(@protein.equivalence["UUG"]).to eq("Leucine")
		end
	end

	context "#Serine" do

		it "UCU => Serine" do
			expect(@protein.equivalence["UCU"]).to eq("Serine")
		end

		it "UCC => Serine" do
			expect(@protein.equivalence["UCC"]).to eq("Serine")
		end

		it "UCA => Serine" do
			expect(@protein.equivalence["UCA"]).to eq("Serine")
		end

		it "UCG => Serine" do
			expect(@protein.equivalence["UCG"]).to eq("Serine")
		end
	end

	context "#Tyrosine" do

		it "UAU  => Tyrosine" do
			expect(@protein.equivalence["UAU"]).to eq("Tyrosine")
		end

		it "UAC => Tyrosine" do
			expect(@protein.equivalence["UAC"]).to eq("Tyrosine")
		end
	end

	context "#Cysteine" do

		it "UGU => Cysteine" do
			expect(@protein.equivalence["UGU"]).to eq("Cysteine")
		end

		it "UGC => Cysteine" do
			expect(@protein.equivalence["UGC"]).to eq("Cysteine")
		end
	end

	context "#Tryptophan"do
		it "UGG => Tryptophan" do
			expect(@protein.equivalence["UGG"]).to eq("Tryptophan")
		end
	end

	context "#Funcionamiento" do
		it "Existe un metodo que dada una cadena te devuelve un array con los 'condon'" do
			expect(@protein.respond_to?:divideStringInCondons).to eq(true)
		end
		it "El metodo tiene que funcionar correctamente " do
			expect(@protein.divideStringInCondons("AUGUUUUCUUAG")).to eq(["AUG", "UUU", "UCU"])
		end
		it "EL metodo de Translate devuelve las proteínas"do
			expect(@protein.translateString("AUGUUUUCUUAG")).to eq(["Methionine","Phenylalanine", "Serine"])
		end
	end

	context "#STOP" do
		it "Debe tener un array para parar la traduccion" do
			expect(@protein.stop).not_to eq(nil)
		end
		it "Debe contener el valor UAA" do
			expect(@protein.stop.include?("UAA")).to eq(true)
		end
		it "Debe incluir el valor UAG"do
			expect(@protein.stop.include?("UAG")).to eq(true)
		end
		it "Debe incluir el valor UGA" do
			expect(@protein.stop.include?("UGA")).to eq(true)
		end
	end
end

=begin
UAU, UAC |Tyrosine

UGU, UGC |Cysteine

UGG |Tryptophan

UAA, UAG, UGA |STOP
=end